import aiohttp
from yarl import URL
import pathlib
import asyncio 
url = URL("https://api.github.com/repos/pineappleEA/pineapple-src/releases")

current_path = pathlib.Path('.')

progress_file = open(current_path / 'progress', 'a+')

progress_file.seek(0)
done = progress_file.readlines()
done = set([x.strip() for x in done])
print(done)
print(f' completed {len(done)} already')

async def download_url_to_file(session, asset, path):

    asset_url = asset['browser_download_url']
    asset_name = asset['name']
    print(f'downloading {asset_name}')
    try:
        async with session.get(asset_url) as r:
            r.raise_for_status()
            with open(path / asset_name, 'wb') as f:
                f.write(await r.read())
    except:
        with open('failures', 'a') as f:
            f.write(f'{asset_url}\n')

async def run():
    
    session = aiohttp.ClientSession()

    for page in range(1,100):
        async with session.get(url.with_query(page=page)) as r:
            data = await r.json()
            for release in data:
                assets = release['assets']
                release_name = release['tag_name']
    
                print(f'downloading release {release_name}')
    
                if release_name in done:
                    print(f'skipping {release_name}')
                    continue
                
                progress_file.write(f'{release_name}\n')
        
                download_path = (current_path / release_name)
                download_path.mkdir(exist_ok=True)
    
                await asyncio.gather(*[download_url_to_file(session, asset, download_path) for asset in assets])
                
asyncio.run(run())
